summaryrefslogtreecommitdiff
path: root/firmware/lib/include/vboot_kernel.h
diff options
context:
space:
mode:
Diffstat (limited to 'firmware/lib/include/vboot_kernel.h')
-rw-r--r--firmware/lib/include/vboot_kernel.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/firmware/lib/include/vboot_kernel.h b/firmware/lib/include/vboot_kernel.h
index 567c10ad..c147c316 100644
--- a/firmware/lib/include/vboot_kernel.h
+++ b/firmware/lib/include/vboot_kernel.h
@@ -54,29 +54,29 @@ int VbUserConfirms(struct vb2_context *ctx, uint32_t confirm_flags);
vb2_error_t VbBootNormal(struct vb2_context *ctx);
/**
- * Handle a developer-mode boot.
+ * Handle a developer-mode boot using legacy clamshell UI.
*/
-vb2_error_t VbBootDeveloper(struct vb2_context *ctx);
+vb2_error_t VbBootDeveloperLegacyClamshell(struct vb2_context *ctx);
/**
- * Handle a diagnostic-mode boot.
+ * Handle a diagnostic-mode boot using legacy clamshell UI.
*/
-vb2_error_t VbBootDiagnostic(struct vb2_context *ctx);
+vb2_error_t VbBootDiagnosticLegacyClamshell(struct vb2_context *ctx);
/**
- * Handle a recovery-mode boot.
+ * Handle a recovery-mode boot using legacy clamshell UI.
*/
-vb2_error_t VbBootRecovery(struct vb2_context *ctx);
+vb2_error_t VbBootRecoveryLegacyClamshell(struct vb2_context *ctx);
/**
* Handle a developer-mode boot using detachable menu ui
*/
-vb2_error_t VbBootDeveloperMenu(struct vb2_context *ctx);
+vb2_error_t VbBootDeveloperLegacyMenu(struct vb2_context *ctx);
/**
* Handle a recovery-mode boot using detachable menu ui
*/
-vb2_error_t VbBootRecoveryMenu(struct vb2_context *ctx);
+vb2_error_t VbBootRecoveryLegacyMenu(struct vb2_context *ctx);
/**
* Writes modified secdata spaces and nvdata.
@@ -54,29 +54,29 @@ int VbUserConfirms(struct vb2_context *ctx, uint32_t confirm_flags);
/**
- * Handle a developer-mode boot using detachable menu ui
+ * Handle a developer-mode boot using legacy menu UI.
*/
@@ -54,29 +54,29 @@ int VbUserConfirms(struct vb2_context *ctx, uint32_t confirm_flags);
/**
- * Handle a recovery-mode boot using detachable menu ui
+ * Handle a recovery-mode boot using legacy menu UI.
*/